<div align="center">
  <img src="https://raw.githubusercontent.com/kap-sh/zapros/refs/heads/main/docs/public/red-spider-side.png" alt="Zapros Logo" width="200">

  # Zapros

  ### Modern and extensible Python HTTP client

  [![PyPI version](https://badge.fury.io/py/zapros.svg)](https://badge.fury.io/py/zapros)
  [![Python 3.10++](https://img.shields.io/badge/python-3.10+-blue.svg)](https://www.python.org/downloads/)
  [![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)

  > **⚠️ Note:** Zapros is a newborn project and may contain bugs. Please report any issues you encounter.

  **[Documentation](https://zapros.dev)**
</div>

---

## 📄 License

This project is licensed under the MIT License - see the [LICENSE](LICENSE) file for details.
